#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Jul 26 21:35:37 2022

@auteur: David Alberto (www.astrolabe-science.fr)
Phileas Fogg fait le tour du monde vers l'Est.
À son retour à Londres, il constate avoir voyagé un jour 
de moins qu'il ne pensait.
Fogg quitte Londres à midi. À chaque passage du Soleil devant
son méridien, Fogg considère qu'un nouveau jour s'est écoulé,
alors que le Soleil a fait moins d'un tour complet.
"""
import matplotlib.pyplot as plt
import matplotlib.patches as patches# cercle, arcs
import numpy as np
from math import ceil# entier supérieur

# -------------------------------------------------
# Paramètres personnalisables
N = 5 # nombre de jours de voyages, selon Fogg.
cols=2 # nombre de colonnes dans le tableau
plt.rcParams["font.family"]="Roboto" # ou autre police installée
plt.rcParams["font.size"]=8
R = 1 # rayon de la Terre sur le schéma
c_Fogg = 'darkviolet' # couleur voyageur
c_Londres = 'navy' # couleur Londres
c_soleil = 'orange' # couleur Soleil
# -------------------------------------------------
lignes=ceil(N/cols) # nombre de lignes
angle_j = 360/N # angle parcouru par jour du voyageur
angle_j_rad=np.radians(angle_j)
# -------------------------------------------------
# Création de la figure et de la liste de graphiques :
fig,axes = plt.subplots(nrows=lignes,ncols=cols,tight_layout=True)
plt.suptitle(f"Le tour du monde en {N} jours",fontsize=15,
             fontweight='bold',y=0.98)
fig.set_size_inches(cols*3, lignes*3)
# axes=axes.T # si on veut classer les graphes par colonne, plutôt que par ligne.
axes=axes.flatten()# rend itérable la liste de graphes.

# succession des jours "ressentis", pour le voyageur :
for k in range(1,N+1):
    ax = axes[k-1]
    ax.set_aspect('equal')
    ax.set_xticks([])
    ax.set_yticks([])
    ax.set_xlim(-2.5*R,2.5*R)
    ax.set_ylim(-2.5*R,2.5*R)
    axcoord=ax.transAxes# conversion en coordonnées normalisées
    angle_fleches=angle_j*k# pour les pointes de flèches des arcs
    #cercle Terre :
    ax.add_patch(patches.Circle((0,0), R,
                                fc='lightblue',
                                ec='darkblue'))
    
    # Point de départ : Londres
    ax.scatter(R,0,s=10,c='r',ec='k')
    ax.text(R-0.1,0,'L',c=c_Londres,va='center',ha='right')
    
    # tracé des méridiens :
    for H in np.arange(0,24):
        theta = np.radians(H*15)
        ax.plot([0,R*np.cos(theta)],[0,R*np.sin(theta)],
                lw=0.5,c='royalblue',alpha=0.5)
    
    # arc du voyageur :
    ax.add_patch(patches.Arc(
        (0,0), 2*(R+0.1), 2*(R+0.1),
        theta1=0,theta2=angle_j*k,ec=c_Fogg))
    ax.scatter(
        (R+0.1)*np.cos(angle_j_rad*k),
        (R+0.1)*np.sin(angle_j_rad*k),
        marker=(3,0,angle_fleches),
               s=10,c=c_Fogg)# triangle au bout de l'arc
    
    # arcs soleil :
    for i in range(1,k):# tours complets du Soleil
        ax.add_patch(patches.Arc((0,0), 2*(R+0.15+i/10), 2*(R+0.15+i/10), theta1=0,
                              theta2=360,ec=c_soleil))
    # arc incomplet du Soleil :
    ax.add_patch(patches.Arc(
        (0,0), 2*(R+0.15+(k)/10), 2*(R+0.15+(k)/10),
        theta1=angle_j*k,
        theta2=0,ec=c_soleil))
    ax.scatter(
        (R+0.15+k/10)*np.cos(angle_j_rad*k),
        (R+0.15+k/10)*np.sin(angle_j_rad*k),
        marker=(3,0,angle_fleches+180),
               s=10,c=c_soleil)# triangle au bout de l'arc

    for j in range(1,k+1):# rayons méridiens :
        ax.plot(
            [0,(R+0.2+N/10)*np.cos(angle_j_rad*j)],
            [0,(R+0.2+N/10)*np.sin(angle_j_rad*j)],
            lw=0.6,c=c_Fogg)
    
    #affichage des indications :
    
    ax.text(0.01,0.06,f'{k}',fontsize=20,
            c=c_Fogg,transform=axcoord)
    if k==1:
        ax.text(0.01,0.01,'jour, selon Fogg',
            c=c_Fogg,transform=axcoord)
    else:
        ax.text(0.01,0.01,'jours, selon Fogg',
            c=c_Fogg,transform=axcoord)
    ax.text(0.99,0.06,f'{k*(1-1/N):.2f}',fontsize=20,
            c=c_Londres,ha='right',transform=axcoord)
    ax.text(0.99,0.01,'jours, selon Londres',
            c=c_Londres,ha='right',transform=axcoord)

# efface les cadres inutilisés :
cadres_vides=cols*lignes-N
for n in range(1,cadres_vides+1):
    axes[-n].axis('off')
# --------------------------------------------------

NomFichier="tourDuMonde_" + str(N)
fig.savefig(NomFichier+".pdf")
fig.savefig(NomFichier+".png",dpi=200)








